.. _fs_average_6_template:

fsaverage6 template
===================

Access
------
See :func:`nilearn.datasets.fetch_surf_fsaverage`.

.. include:: fsaverage_content.rst

Notes
-----
Fsaverage6 standard surface as distributed with Freesurfer (:footcite:t:`Fischl1999`).

References
----------
.. footbibliography::

License
-------
unknown
